# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatabaseInstanceArgs', 'DatabaseInstance']

@pulumi.input_type
class DatabaseInstanceArgs:
    def __init__(__self__, *,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]] = None,
                 enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 parent_instance_ref: Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DatabaseInstance resource.
        :param pulumi.Input[_builtins.str] capacity: The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]] custom_tags: Custom tags associated with the instance. This field is only included on create and update responses
        :param pulumi.Input[_builtins.bool] enable_pg_native_login: Whether to enable PG native password login on the instance. Defaults to false
        :param pulumi.Input[_builtins.bool] enable_readable_secondaries: Whether to enable secondaries to serve read-only traffic. Defaults to false
        :param pulumi.Input[_builtins.str] name: The name of the instance. This is the unique identifier for the instance
        :param pulumi.Input[_builtins.int] node_count: The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        :param pulumi.Input['DatabaseInstanceParentInstanceRefArgs'] parent_instance_ref: The ref of the parent instance. This is only available if the instance is
               child instance.
               Input: For specifying the parent instance to create a child instance. Optional.
               Output: Only populated if provided as input to create a child instance
        :param pulumi.Input[_builtins.bool] purge_on_delete: Purge the resource on delete
        :param pulumi.Input[_builtins.int] retention_window_in_days: The retention window for the instance. This is the time window in days
               for which the historical data is retained. The default value is 7 days.
               Valid values are 2 to 35 days
        :param pulumi.Input[_builtins.bool] stopped: Whether to stop the instance. An input only param, see effective_stopped for the output
        :param pulumi.Input[_builtins.str] usage_policy_id: The desired usage policy to associate with the instance
        """
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if custom_tags is not None:
            pulumi.set(__self__, "custom_tags", custom_tags)
        if enable_pg_native_login is not None:
            pulumi.set(__self__, "enable_pg_native_login", enable_pg_native_login)
        if enable_readable_secondaries is not None:
            pulumi.set(__self__, "enable_readable_secondaries", enable_readable_secondaries)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_count is not None:
            pulumi.set(__self__, "node_count", node_count)
        if parent_instance_ref is not None:
            pulumi.set(__self__, "parent_instance_ref", parent_instance_ref)
        if purge_on_delete is not None:
            pulumi.set(__self__, "purge_on_delete", purge_on_delete)
        if retention_window_in_days is not None:
            pulumi.set(__self__, "retention_window_in_days", retention_window_in_days)
        if stopped is not None:
            pulumi.set(__self__, "stopped", stopped)
        if usage_policy_id is not None:
            pulumi.set(__self__, "usage_policy_id", usage_policy_id)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "capacity", value)

    @_builtins.property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]]:
        """
        Custom tags associated with the instance. This field is only included on create and update responses
        """
        return pulumi.get(self, "custom_tags")

    @custom_tags.setter
    def custom_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]]):
        pulumi.set(self, "custom_tags", value)

    @_builtins.property
    @pulumi.getter(name="enablePgNativeLogin")
    def enable_pg_native_login(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable PG native password login on the instance. Defaults to false
        """
        return pulumi.get(self, "enable_pg_native_login")

    @enable_pg_native_login.setter
    def enable_pg_native_login(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_pg_native_login", value)

    @_builtins.property
    @pulumi.getter(name="enableReadableSecondaries")
    def enable_readable_secondaries(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable secondaries to serve read-only traffic. Defaults to false
        """
        return pulumi.get(self, "enable_readable_secondaries")

    @enable_readable_secondaries.setter
    def enable_readable_secondaries(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_readable_secondaries", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the instance. This is the unique identifier for the instance
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        """
        return pulumi.get(self, "node_count")

    @node_count.setter
    def node_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "node_count", value)

    @_builtins.property
    @pulumi.getter(name="parentInstanceRef")
    def parent_instance_ref(self) -> Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']]:
        """
        The ref of the parent instance. This is only available if the instance is
        child instance.
        Input: For specifying the parent instance to create a child instance. Optional.
        Output: Only populated if provided as input to create a child instance
        """
        return pulumi.get(self, "parent_instance_ref")

    @parent_instance_ref.setter
    def parent_instance_ref(self, value: Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']]):
        pulumi.set(self, "parent_instance_ref", value)

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Purge the resource on delete
        """
        return pulumi.get(self, "purge_on_delete")

    @purge_on_delete.setter
    def purge_on_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "purge_on_delete", value)

    @_builtins.property
    @pulumi.getter(name="retentionWindowInDays")
    def retention_window_in_days(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The retention window for the instance. This is the time window in days
        for which the historical data is retained. The default value is 7 days.
        Valid values are 2 to 35 days
        """
        return pulumi.get(self, "retention_window_in_days")

    @retention_window_in_days.setter
    def retention_window_in_days(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "retention_window_in_days", value)

    @_builtins.property
    @pulumi.getter
    def stopped(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to stop the instance. An input only param, see effective_stopped for the output
        """
        return pulumi.get(self, "stopped")

    @stopped.setter
    def stopped(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "stopped", value)

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The desired usage policy to associate with the instance
        """
        return pulumi.get(self, "usage_policy_id")

    @usage_policy_id.setter
    def usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage_policy_id", value)


@pulumi.input_type
class _DatabaseInstanceState:
    def __init__(__self__, *,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 child_instance_refs: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceChildInstanceRefArgs']]]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.str]] = None,
                 creator: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]] = None,
                 effective_capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceEffectiveCustomTagArgs']]]] = None,
                 effective_enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 effective_enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 effective_node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 effective_retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 effective_stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 effective_usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 parent_instance_ref: Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']] = None,
                 pg_version: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 read_only_dns: Optional[pulumi.Input[_builtins.str]] = None,
                 read_write_dns: Optional[pulumi.Input[_builtins.str]] = None,
                 retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 uid: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DatabaseInstance resources.
        :param pulumi.Input[_builtins.str] capacity: The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceChildInstanceRefArgs']]] child_instance_refs: (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
               parent instance
        :param pulumi.Input[_builtins.str] creation_time: (string) - The timestamp when the instance was created
        :param pulumi.Input[_builtins.str] creator: (string) - The email of the creator of the instance
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]] custom_tags: Custom tags associated with the instance. This field is only included on create and update responses
        :param pulumi.Input[_builtins.str] effective_capacity: (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceEffectiveCustomTagArgs']]] effective_custom_tags: (list of CustomTag) - The recorded custom tags associated with the instance
        :param pulumi.Input[_builtins.bool] effective_enable_pg_native_login: (boolean) - Whether the instance has PG native password login enabled
        :param pulumi.Input[_builtins.bool] effective_enable_readable_secondaries: (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false
        :param pulumi.Input[_builtins.int] effective_node_count: (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries
        :param pulumi.Input[_builtins.int] effective_retention_window_in_days: (integer) - The retention window for the instance. This is the time window in days
               for which the historical data is retained
        :param pulumi.Input[_builtins.bool] effective_stopped: (boolean) - Whether the instance is stopped
        :param pulumi.Input[_builtins.str] effective_usage_policy_id: (string) - The policy that is applied to the instance
        :param pulumi.Input[_builtins.bool] enable_pg_native_login: Whether to enable PG native password login on the instance. Defaults to false
        :param pulumi.Input[_builtins.bool] enable_readable_secondaries: Whether to enable secondaries to serve read-only traffic. Defaults to false
        :param pulumi.Input[_builtins.str] name: The name of the instance. This is the unique identifier for the instance
        :param pulumi.Input[_builtins.int] node_count: The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        :param pulumi.Input['DatabaseInstanceParentInstanceRefArgs'] parent_instance_ref: The ref of the parent instance. This is only available if the instance is
               child instance.
               Input: For specifying the parent instance to create a child instance. Optional.
               Output: Only populated if provided as input to create a child instance
        :param pulumi.Input[_builtins.str] pg_version: (string) - The version of Postgres running on the instance
        :param pulumi.Input[_builtins.bool] purge_on_delete: Purge the resource on delete
        :param pulumi.Input[_builtins.str] read_only_dns: (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
               enable_readable_secondaries is true
        :param pulumi.Input[_builtins.str] read_write_dns: (string) - The DNS endpoint to connect to the instance for read+write access
        :param pulumi.Input[_builtins.int] retention_window_in_days: The retention window for the instance. This is the time window in days
               for which the historical data is retained. The default value is 7 days.
               Valid values are 2 to 35 days
        :param pulumi.Input[_builtins.str] state: (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        :param pulumi.Input[_builtins.bool] stopped: Whether to stop the instance. An input only param, see effective_stopped for the output
        :param pulumi.Input[_builtins.str] uid: (string) - Id of the ref database instance
        :param pulumi.Input[_builtins.str] usage_policy_id: The desired usage policy to associate with the instance
        """
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if child_instance_refs is not None:
            pulumi.set(__self__, "child_instance_refs", child_instance_refs)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if custom_tags is not None:
            pulumi.set(__self__, "custom_tags", custom_tags)
        if effective_capacity is not None:
            pulumi.set(__self__, "effective_capacity", effective_capacity)
        if effective_custom_tags is not None:
            pulumi.set(__self__, "effective_custom_tags", effective_custom_tags)
        if effective_enable_pg_native_login is not None:
            pulumi.set(__self__, "effective_enable_pg_native_login", effective_enable_pg_native_login)
        if effective_enable_readable_secondaries is not None:
            pulumi.set(__self__, "effective_enable_readable_secondaries", effective_enable_readable_secondaries)
        if effective_node_count is not None:
            pulumi.set(__self__, "effective_node_count", effective_node_count)
        if effective_retention_window_in_days is not None:
            pulumi.set(__self__, "effective_retention_window_in_days", effective_retention_window_in_days)
        if effective_stopped is not None:
            pulumi.set(__self__, "effective_stopped", effective_stopped)
        if effective_usage_policy_id is not None:
            pulumi.set(__self__, "effective_usage_policy_id", effective_usage_policy_id)
        if enable_pg_native_login is not None:
            pulumi.set(__self__, "enable_pg_native_login", enable_pg_native_login)
        if enable_readable_secondaries is not None:
            pulumi.set(__self__, "enable_readable_secondaries", enable_readable_secondaries)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_count is not None:
            pulumi.set(__self__, "node_count", node_count)
        if parent_instance_ref is not None:
            pulumi.set(__self__, "parent_instance_ref", parent_instance_ref)
        if pg_version is not None:
            pulumi.set(__self__, "pg_version", pg_version)
        if purge_on_delete is not None:
            pulumi.set(__self__, "purge_on_delete", purge_on_delete)
        if read_only_dns is not None:
            pulumi.set(__self__, "read_only_dns", read_only_dns)
        if read_write_dns is not None:
            pulumi.set(__self__, "read_write_dns", read_write_dns)
        if retention_window_in_days is not None:
            pulumi.set(__self__, "retention_window_in_days", retention_window_in_days)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if stopped is not None:
            pulumi.set(__self__, "stopped", stopped)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if usage_policy_id is not None:
            pulumi.set(__self__, "usage_policy_id", usage_policy_id)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "capacity", value)

    @_builtins.property
    @pulumi.getter(name="childInstanceRefs")
    def child_instance_refs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceChildInstanceRefArgs']]]]:
        """
        (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
        parent instance
        """
        return pulumi.get(self, "child_instance_refs")

    @child_instance_refs.setter
    def child_instance_refs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceChildInstanceRefArgs']]]]):
        pulumi.set(self, "child_instance_refs", value)

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The timestamp when the instance was created
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creation_time", value)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The email of the creator of the instance
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator", value)

    @_builtins.property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]]:
        """
        Custom tags associated with the instance. This field is only included on create and update responses
        """
        return pulumi.get(self, "custom_tags")

    @custom_tags.setter
    def custom_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]]):
        pulumi.set(self, "custom_tags", value)

    @_builtins.property
    @pulumi.getter(name="effectiveCapacity")
    def effective_capacity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity
        """
        return pulumi.get(self, "effective_capacity")

    @effective_capacity.setter
    def effective_capacity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_capacity", value)

    @_builtins.property
    @pulumi.getter(name="effectiveCustomTags")
    def effective_custom_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceEffectiveCustomTagArgs']]]]:
        """
        (list of CustomTag) - The recorded custom tags associated with the instance
        """
        return pulumi.get(self, "effective_custom_tags")

    @effective_custom_tags.setter
    def effective_custom_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceEffectiveCustomTagArgs']]]]):
        pulumi.set(self, "effective_custom_tags", value)

    @_builtins.property
    @pulumi.getter(name="effectiveEnablePgNativeLogin")
    def effective_enable_pg_native_login(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (boolean) - Whether the instance has PG native password login enabled
        """
        return pulumi.get(self, "effective_enable_pg_native_login")

    @effective_enable_pg_native_login.setter
    def effective_enable_pg_native_login(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "effective_enable_pg_native_login", value)

    @_builtins.property
    @pulumi.getter(name="effectiveEnableReadableSecondaries")
    def effective_enable_readable_secondaries(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false
        """
        return pulumi.get(self, "effective_enable_readable_secondaries")

    @effective_enable_readable_secondaries.setter
    def effective_enable_readable_secondaries(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "effective_enable_readable_secondaries", value)

    @_builtins.property
    @pulumi.getter(name="effectiveNodeCount")
    def effective_node_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries
        """
        return pulumi.get(self, "effective_node_count")

    @effective_node_count.setter
    def effective_node_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "effective_node_count", value)

    @_builtins.property
    @pulumi.getter(name="effectiveRetentionWindowInDays")
    def effective_retention_window_in_days(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - The retention window for the instance. This is the time window in days
        for which the historical data is retained
        """
        return pulumi.get(self, "effective_retention_window_in_days")

    @effective_retention_window_in_days.setter
    def effective_retention_window_in_days(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "effective_retention_window_in_days", value)

    @_builtins.property
    @pulumi.getter(name="effectiveStopped")
    def effective_stopped(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (boolean) - Whether the instance is stopped
        """
        return pulumi.get(self, "effective_stopped")

    @effective_stopped.setter
    def effective_stopped(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "effective_stopped", value)

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The policy that is applied to the instance
        """
        return pulumi.get(self, "effective_usage_policy_id")

    @effective_usage_policy_id.setter
    def effective_usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_usage_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="enablePgNativeLogin")
    def enable_pg_native_login(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable PG native password login on the instance. Defaults to false
        """
        return pulumi.get(self, "enable_pg_native_login")

    @enable_pg_native_login.setter
    def enable_pg_native_login(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_pg_native_login", value)

    @_builtins.property
    @pulumi.getter(name="enableReadableSecondaries")
    def enable_readable_secondaries(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable secondaries to serve read-only traffic. Defaults to false
        """
        return pulumi.get(self, "enable_readable_secondaries")

    @enable_readable_secondaries.setter
    def enable_readable_secondaries(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_readable_secondaries", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the instance. This is the unique identifier for the instance
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        """
        return pulumi.get(self, "node_count")

    @node_count.setter
    def node_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "node_count", value)

    @_builtins.property
    @pulumi.getter(name="parentInstanceRef")
    def parent_instance_ref(self) -> Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']]:
        """
        The ref of the parent instance. This is only available if the instance is
        child instance.
        Input: For specifying the parent instance to create a child instance. Optional.
        Output: Only populated if provided as input to create a child instance
        """
        return pulumi.get(self, "parent_instance_ref")

    @parent_instance_ref.setter
    def parent_instance_ref(self, value: Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']]):
        pulumi.set(self, "parent_instance_ref", value)

    @_builtins.property
    @pulumi.getter(name="pgVersion")
    def pg_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The version of Postgres running on the instance
        """
        return pulumi.get(self, "pg_version")

    @pg_version.setter
    def pg_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pg_version", value)

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Purge the resource on delete
        """
        return pulumi.get(self, "purge_on_delete")

    @purge_on_delete.setter
    def purge_on_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "purge_on_delete", value)

    @_builtins.property
    @pulumi.getter(name="readOnlyDns")
    def read_only_dns(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
        enable_readable_secondaries is true
        """
        return pulumi.get(self, "read_only_dns")

    @read_only_dns.setter
    def read_only_dns(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "read_only_dns", value)

    @_builtins.property
    @pulumi.getter(name="readWriteDns")
    def read_write_dns(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The DNS endpoint to connect to the instance for read+write access
        """
        return pulumi.get(self, "read_write_dns")

    @read_write_dns.setter
    def read_write_dns(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "read_write_dns", value)

    @_builtins.property
    @pulumi.getter(name="retentionWindowInDays")
    def retention_window_in_days(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The retention window for the instance. This is the time window in days
        for which the historical data is retained. The default value is 7 days.
        Valid values are 2 to 35 days
        """
        return pulumi.get(self, "retention_window_in_days")

    @retention_window_in_days.setter
    def retention_window_in_days(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "retention_window_in_days", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter
    def stopped(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to stop the instance. An input only param, see effective_stopped for the output
        """
        return pulumi.get(self, "stopped")

    @stopped.setter
    def stopped(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "stopped", value)

    @_builtins.property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Id of the ref database instance
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "uid", value)

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The desired usage policy to associate with the instance
        """
        return pulumi.get(self, "usage_policy_id")

    @usage_policy_id.setter
    def usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage_policy_id", value)


@pulumi.type_token("databricks:index/databaseInstance:DatabaseInstance")
class DatabaseInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]]] = None,
                 enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 parent_instance_ref: Optional[pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Lakebase Database Instances are managed Postgres instances, composed of a primary Postgres compute instance and 0 or more read replica instances.

        ## Example Usage

        ### Basic Example

        This example creates a simple Database Instance with the specified name and capacity.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_2")
        ```

        ### Example with Readable Secondaries

        This example creates a Database Instance with readable secondaries (and HA) enabled.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_2",
            node_count=2,
            enable_readable_secondaries=True)
        ```

        ### Example Child Instance Created From Parent

        This example creates a child Database Instance from a specified parent Database Instance at the current point in time.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        child = databricks.DatabaseInstance("child",
            name="my-database-instance",
            capacity="CU_2",
            parent_instance_ref={
                "name": "my-parent-instance",
            })
        ```

        ### Example with a usage policy and custom tags

        This example creates a Database Instance with an associated usage policy and custom tags.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_8",
            usage_policy_id="948192fa-a98b-498f-a09b-ecee79d8b983",
            custom_tags=[
                {
                    "key": "custom_tag_key1",
                    "value": "custom_tag_value1",
                },
                {
                    "key": "custom_tag_key2",
                    "value": "custom_tag_value2",
                },
            ])
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_database_instance.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/databaseInstance:DatabaseInstance this "name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] capacity: The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]] custom_tags: Custom tags associated with the instance. This field is only included on create and update responses
        :param pulumi.Input[_builtins.bool] enable_pg_native_login: Whether to enable PG native password login on the instance. Defaults to false
        :param pulumi.Input[_builtins.bool] enable_readable_secondaries: Whether to enable secondaries to serve read-only traffic. Defaults to false
        :param pulumi.Input[_builtins.str] name: The name of the instance. This is the unique identifier for the instance
        :param pulumi.Input[_builtins.int] node_count: The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        :param pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']] parent_instance_ref: The ref of the parent instance. This is only available if the instance is
               child instance.
               Input: For specifying the parent instance to create a child instance. Optional.
               Output: Only populated if provided as input to create a child instance
        :param pulumi.Input[_builtins.bool] purge_on_delete: Purge the resource on delete
        :param pulumi.Input[_builtins.int] retention_window_in_days: The retention window for the instance. This is the time window in days
               for which the historical data is retained. The default value is 7 days.
               Valid values are 2 to 35 days
        :param pulumi.Input[_builtins.bool] stopped: Whether to stop the instance. An input only param, see effective_stopped for the output
        :param pulumi.Input[_builtins.str] usage_policy_id: The desired usage policy to associate with the instance
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DatabaseInstanceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Lakebase Database Instances are managed Postgres instances, composed of a primary Postgres compute instance and 0 or more read replica instances.

        ## Example Usage

        ### Basic Example

        This example creates a simple Database Instance with the specified name and capacity.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_2")
        ```

        ### Example with Readable Secondaries

        This example creates a Database Instance with readable secondaries (and HA) enabled.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_2",
            node_count=2,
            enable_readable_secondaries=True)
        ```

        ### Example Child Instance Created From Parent

        This example creates a child Database Instance from a specified parent Database Instance at the current point in time.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        child = databricks.DatabaseInstance("child",
            name="my-database-instance",
            capacity="CU_2",
            parent_instance_ref={
                "name": "my-parent-instance",
            })
        ```

        ### Example with a usage policy and custom tags

        This example creates a Database Instance with an associated usage policy and custom tags.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_8",
            usage_policy_id="948192fa-a98b-498f-a09b-ecee79d8b983",
            custom_tags=[
                {
                    "key": "custom_tag_key1",
                    "value": "custom_tag_value1",
                },
                {
                    "key": "custom_tag_key2",
                    "value": "custom_tag_value2",
                },
            ])
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_database_instance.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/databaseInstance:DatabaseInstance this "name"
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]]] = None,
                 enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 parent_instance_ref: Optional[pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseInstanceArgs.__new__(DatabaseInstanceArgs)

            __props__.__dict__["capacity"] = capacity
            __props__.__dict__["custom_tags"] = custom_tags
            __props__.__dict__["enable_pg_native_login"] = enable_pg_native_login
            __props__.__dict__["enable_readable_secondaries"] = enable_readable_secondaries
            __props__.__dict__["name"] = name
            __props__.__dict__["node_count"] = node_count
            __props__.__dict__["parent_instance_ref"] = parent_instance_ref
            __props__.__dict__["purge_on_delete"] = purge_on_delete
            __props__.__dict__["retention_window_in_days"] = retention_window_in_days
            __props__.__dict__["stopped"] = stopped
            __props__.__dict__["usage_policy_id"] = usage_policy_id
            __props__.__dict__["child_instance_refs"] = None
            __props__.__dict__["creation_time"] = None
            __props__.__dict__["creator"] = None
            __props__.__dict__["effective_capacity"] = None
            __props__.__dict__["effective_custom_tags"] = None
            __props__.__dict__["effective_enable_pg_native_login"] = None
            __props__.__dict__["effective_enable_readable_secondaries"] = None
            __props__.__dict__["effective_node_count"] = None
            __props__.__dict__["effective_retention_window_in_days"] = None
            __props__.__dict__["effective_stopped"] = None
            __props__.__dict__["effective_usage_policy_id"] = None
            __props__.__dict__["pg_version"] = None
            __props__.__dict__["read_only_dns"] = None
            __props__.__dict__["read_write_dns"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["uid"] = None
        super(DatabaseInstance, __self__).__init__(
            'databricks:index/databaseInstance:DatabaseInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacity: Optional[pulumi.Input[_builtins.str]] = None,
            child_instance_refs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceChildInstanceRefArgs', 'DatabaseInstanceChildInstanceRefArgsDict']]]]] = None,
            creation_time: Optional[pulumi.Input[_builtins.str]] = None,
            creator: Optional[pulumi.Input[_builtins.str]] = None,
            custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]]] = None,
            effective_capacity: Optional[pulumi.Input[_builtins.str]] = None,
            effective_custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceEffectiveCustomTagArgs', 'DatabaseInstanceEffectiveCustomTagArgsDict']]]]] = None,
            effective_enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
            effective_enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
            effective_node_count: Optional[pulumi.Input[_builtins.int]] = None,
            effective_retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
            effective_stopped: Optional[pulumi.Input[_builtins.bool]] = None,
            effective_usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
            enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            node_count: Optional[pulumi.Input[_builtins.int]] = None,
            parent_instance_ref: Optional[pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']]] = None,
            pg_version: Optional[pulumi.Input[_builtins.str]] = None,
            purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            read_only_dns: Optional[pulumi.Input[_builtins.str]] = None,
            read_write_dns: Optional[pulumi.Input[_builtins.str]] = None,
            retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            stopped: Optional[pulumi.Input[_builtins.bool]] = None,
            uid: Optional[pulumi.Input[_builtins.str]] = None,
            usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'DatabaseInstance':
        """
        Get an existing DatabaseInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] capacity: The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceChildInstanceRefArgs', 'DatabaseInstanceChildInstanceRefArgsDict']]]] child_instance_refs: (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
               parent instance
        :param pulumi.Input[_builtins.str] creation_time: (string) - The timestamp when the instance was created
        :param pulumi.Input[_builtins.str] creator: (string) - The email of the creator of the instance
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]] custom_tags: Custom tags associated with the instance. This field is only included on create and update responses
        :param pulumi.Input[_builtins.str] effective_capacity: (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceEffectiveCustomTagArgs', 'DatabaseInstanceEffectiveCustomTagArgsDict']]]] effective_custom_tags: (list of CustomTag) - The recorded custom tags associated with the instance
        :param pulumi.Input[_builtins.bool] effective_enable_pg_native_login: (boolean) - Whether the instance has PG native password login enabled
        :param pulumi.Input[_builtins.bool] effective_enable_readable_secondaries: (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false
        :param pulumi.Input[_builtins.int] effective_node_count: (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries
        :param pulumi.Input[_builtins.int] effective_retention_window_in_days: (integer) - The retention window for the instance. This is the time window in days
               for which the historical data is retained
        :param pulumi.Input[_builtins.bool] effective_stopped: (boolean) - Whether the instance is stopped
        :param pulumi.Input[_builtins.str] effective_usage_policy_id: (string) - The policy that is applied to the instance
        :param pulumi.Input[_builtins.bool] enable_pg_native_login: Whether to enable PG native password login on the instance. Defaults to false
        :param pulumi.Input[_builtins.bool] enable_readable_secondaries: Whether to enable secondaries to serve read-only traffic. Defaults to false
        :param pulumi.Input[_builtins.str] name: The name of the instance. This is the unique identifier for the instance
        :param pulumi.Input[_builtins.int] node_count: The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        :param pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']] parent_instance_ref: The ref of the parent instance. This is only available if the instance is
               child instance.
               Input: For specifying the parent instance to create a child instance. Optional.
               Output: Only populated if provided as input to create a child instance
        :param pulumi.Input[_builtins.str] pg_version: (string) - The version of Postgres running on the instance
        :param pulumi.Input[_builtins.bool] purge_on_delete: Purge the resource on delete
        :param pulumi.Input[_builtins.str] read_only_dns: (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
               enable_readable_secondaries is true
        :param pulumi.Input[_builtins.str] read_write_dns: (string) - The DNS endpoint to connect to the instance for read+write access
        :param pulumi.Input[_builtins.int] retention_window_in_days: The retention window for the instance. This is the time window in days
               for which the historical data is retained. The default value is 7 days.
               Valid values are 2 to 35 days
        :param pulumi.Input[_builtins.str] state: (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        :param pulumi.Input[_builtins.bool] stopped: Whether to stop the instance. An input only param, see effective_stopped for the output
        :param pulumi.Input[_builtins.str] uid: (string) - Id of the ref database instance
        :param pulumi.Input[_builtins.str] usage_policy_id: The desired usage policy to associate with the instance
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseInstanceState.__new__(_DatabaseInstanceState)

        __props__.__dict__["capacity"] = capacity
        __props__.__dict__["child_instance_refs"] = child_instance_refs
        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["creator"] = creator
        __props__.__dict__["custom_tags"] = custom_tags
        __props__.__dict__["effective_capacity"] = effective_capacity
        __props__.__dict__["effective_custom_tags"] = effective_custom_tags
        __props__.__dict__["effective_enable_pg_native_login"] = effective_enable_pg_native_login
        __props__.__dict__["effective_enable_readable_secondaries"] = effective_enable_readable_secondaries
        __props__.__dict__["effective_node_count"] = effective_node_count
        __props__.__dict__["effective_retention_window_in_days"] = effective_retention_window_in_days
        __props__.__dict__["effective_stopped"] = effective_stopped
        __props__.__dict__["effective_usage_policy_id"] = effective_usage_policy_id
        __props__.__dict__["enable_pg_native_login"] = enable_pg_native_login
        __props__.__dict__["enable_readable_secondaries"] = enable_readable_secondaries
        __props__.__dict__["name"] = name
        __props__.__dict__["node_count"] = node_count
        __props__.__dict__["parent_instance_ref"] = parent_instance_ref
        __props__.__dict__["pg_version"] = pg_version
        __props__.__dict__["purge_on_delete"] = purge_on_delete
        __props__.__dict__["read_only_dns"] = read_only_dns
        __props__.__dict__["read_write_dns"] = read_write_dns
        __props__.__dict__["retention_window_in_days"] = retention_window_in_days
        __props__.__dict__["state"] = state
        __props__.__dict__["stopped"] = stopped
        __props__.__dict__["uid"] = uid
        __props__.__dict__["usage_policy_id"] = usage_policy_id
        return DatabaseInstance(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @_builtins.property
    @pulumi.getter(name="childInstanceRefs")
    def child_instance_refs(self) -> pulumi.Output[Sequence['outputs.DatabaseInstanceChildInstanceRef']]:
        """
        (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
        parent instance
        """
        return pulumi.get(self, "child_instance_refs")

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The timestamp when the instance was created
        """
        return pulumi.get(self, "creation_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The email of the creator of the instance
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> pulumi.Output[Sequence['outputs.DatabaseInstanceCustomTag']]:
        """
        Custom tags associated with the instance. This field is only included on create and update responses
        """
        return pulumi.get(self, "custom_tags")

    @_builtins.property
    @pulumi.getter(name="effectiveCapacity")
    def effective_capacity(self) -> pulumi.Output[_builtins.str]:
        """
        (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity
        """
        return pulumi.get(self, "effective_capacity")

    @_builtins.property
    @pulumi.getter(name="effectiveCustomTags")
    def effective_custom_tags(self) -> pulumi.Output[Sequence['outputs.DatabaseInstanceEffectiveCustomTag']]:
        """
        (list of CustomTag) - The recorded custom tags associated with the instance
        """
        return pulumi.get(self, "effective_custom_tags")

    @_builtins.property
    @pulumi.getter(name="effectiveEnablePgNativeLogin")
    def effective_enable_pg_native_login(self) -> pulumi.Output[_builtins.bool]:
        """
        (boolean) - Whether the instance has PG native password login enabled
        """
        return pulumi.get(self, "effective_enable_pg_native_login")

    @_builtins.property
    @pulumi.getter(name="effectiveEnableReadableSecondaries")
    def effective_enable_readable_secondaries(self) -> pulumi.Output[_builtins.bool]:
        """
        (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false
        """
        return pulumi.get(self, "effective_enable_readable_secondaries")

    @_builtins.property
    @pulumi.getter(name="effectiveNodeCount")
    def effective_node_count(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries
        """
        return pulumi.get(self, "effective_node_count")

    @_builtins.property
    @pulumi.getter(name="effectiveRetentionWindowInDays")
    def effective_retention_window_in_days(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - The retention window for the instance. This is the time window in days
        for which the historical data is retained
        """
        return pulumi.get(self, "effective_retention_window_in_days")

    @_builtins.property
    @pulumi.getter(name="effectiveStopped")
    def effective_stopped(self) -> pulumi.Output[_builtins.bool]:
        """
        (boolean) - Whether the instance is stopped
        """
        return pulumi.get(self, "effective_stopped")

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The policy that is applied to the instance
        """
        return pulumi.get(self, "effective_usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="enablePgNativeLogin")
    def enable_pg_native_login(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to enable PG native password login on the instance. Defaults to false
        """
        return pulumi.get(self, "enable_pg_native_login")

    @_builtins.property
    @pulumi.getter(name="enableReadableSecondaries")
    def enable_readable_secondaries(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to enable secondaries to serve read-only traffic. Defaults to false
        """
        return pulumi.get(self, "enable_readable_secondaries")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the instance. This is the unique identifier for the instance
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> pulumi.Output[_builtins.int]:
        """
        The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        """
        return pulumi.get(self, "node_count")

    @_builtins.property
    @pulumi.getter(name="parentInstanceRef")
    def parent_instance_ref(self) -> pulumi.Output[Optional['outputs.DatabaseInstanceParentInstanceRef']]:
        """
        The ref of the parent instance. This is only available if the instance is
        child instance.
        Input: For specifying the parent instance to create a child instance. Optional.
        Output: Only populated if provided as input to create a child instance
        """
        return pulumi.get(self, "parent_instance_ref")

    @_builtins.property
    @pulumi.getter(name="pgVersion")
    def pg_version(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The version of Postgres running on the instance
        """
        return pulumi.get(self, "pg_version")

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Purge the resource on delete
        """
        return pulumi.get(self, "purge_on_delete")

    @_builtins.property
    @pulumi.getter(name="readOnlyDns")
    def read_only_dns(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
        enable_readable_secondaries is true
        """
        return pulumi.get(self, "read_only_dns")

    @_builtins.property
    @pulumi.getter(name="readWriteDns")
    def read_write_dns(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The DNS endpoint to connect to the instance for read+write access
        """
        return pulumi.get(self, "read_write_dns")

    @_builtins.property
    @pulumi.getter(name="retentionWindowInDays")
    def retention_window_in_days(self) -> pulumi.Output[_builtins.int]:
        """
        The retention window for the instance. This is the time window in days
        for which the historical data is retained. The default value is 7 days.
        Valid values are 2 to 35 days
        """
        return pulumi.get(self, "retention_window_in_days")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def stopped(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to stop the instance. An input only param, see effective_stopped for the output
        """
        return pulumi.get(self, "stopped")

    @_builtins.property
    @pulumi.getter
    def uid(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Id of the ref database instance
        """
        return pulumi.get(self, "uid")

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        The desired usage policy to associate with the instance
        """
        return pulumi.get(self, "usage_policy_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MwsCustomerManagedKeysArgs', 'MwsCustomerManagedKeys']

@pulumi.input_type
class MwsCustomerManagedKeysArgs:
    def __init__(__self__, *,
                 account_id: pulumi.Input[_builtins.str],
                 use_cases: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 aws_key_info: Optional[pulumi.Input['MwsCustomerManagedKeysAwsKeyInfoArgs']] = None,
                 creation_time: Optional[pulumi.Input[_builtins.int]] = None,
                 customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcp_key_info: Optional[pulumi.Input['MwsCustomerManagedKeysGcpKeyInfoArgs']] = None):
        """
        The set of arguments for constructing a MwsCustomerManagedKeys resource.
        :param pulumi.Input[_builtins.str] account_id: Account Id that could be found in the top right corner of [Accounts Console](https://accounts.cloud.databricks.com/)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] use_cases: *(since v0.3.4)* List of use cases for which this key will be used. *If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.* Possible values are:
               * `MANAGED_SERVICES` - for encryption of the workspace objects (notebooks, secrets) that are stored in the control plane
               * `STORAGE` - for encryption of the DBFS Storage & Cluster EBS Volumes
        :param pulumi.Input['MwsCustomerManagedKeysAwsKeyInfoArgs'] aws_key_info: This field is a block and is documented below. This conflicts with `gcp_key_info`
        :param pulumi.Input[_builtins.int] creation_time: (Integer) Time in epoch milliseconds when the customer key was created.
        :param pulumi.Input[_builtins.str] customer_managed_key_id: (String) ID of the encryption key configuration object.
        :param pulumi.Input['MwsCustomerManagedKeysGcpKeyInfoArgs'] gcp_key_info: This field is a block and is documented below. This conflicts with `aws_key_info`
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "use_cases", use_cases)
        if aws_key_info is not None:
            pulumi.set(__self__, "aws_key_info", aws_key_info)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if customer_managed_key_id is not None:
            pulumi.set(__self__, "customer_managed_key_id", customer_managed_key_id)
        if gcp_key_info is not None:
            pulumi.set(__self__, "gcp_key_info", gcp_key_info)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Input[_builtins.str]:
        """
        Account Id that could be found in the top right corner of [Accounts Console](https://accounts.cloud.databricks.com/)
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="useCases")
    def use_cases(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        *(since v0.3.4)* List of use cases for which this key will be used. *If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.* Possible values are:
        * `MANAGED_SERVICES` - for encryption of the workspace objects (notebooks, secrets) that are stored in the control plane
        * `STORAGE` - for encryption of the DBFS Storage & Cluster EBS Volumes
        """
        return pulumi.get(self, "use_cases")

    @use_cases.setter
    def use_cases(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "use_cases", value)

    @_builtins.property
    @pulumi.getter(name="awsKeyInfo")
    def aws_key_info(self) -> Optional[pulumi.Input['MwsCustomerManagedKeysAwsKeyInfoArgs']]:
        """
        This field is a block and is documented below. This conflicts with `gcp_key_info`
        """
        return pulumi.get(self, "aws_key_info")

    @aws_key_info.setter
    def aws_key_info(self, value: Optional[pulumi.Input['MwsCustomerManagedKeysAwsKeyInfoArgs']]):
        pulumi.set(self, "aws_key_info", value)

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (Integer) Time in epoch milliseconds when the customer key was created.
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "creation_time", value)

    @_builtins.property
    @pulumi.getter(name="customerManagedKeyId")
    def customer_managed_key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (String) ID of the encryption key configuration object.
        """
        return pulumi.get(self, "customer_managed_key_id")

    @customer_managed_key_id.setter
    def customer_managed_key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "customer_managed_key_id", value)

    @_builtins.property
    @pulumi.getter(name="gcpKeyInfo")
    def gcp_key_info(self) -> Optional[pulumi.Input['MwsCustomerManagedKeysGcpKeyInfoArgs']]:
        """
        This field is a block and is documented below. This conflicts with `aws_key_info`
        """
        return pulumi.get(self, "gcp_key_info")

    @gcp_key_info.setter
    def gcp_key_info(self, value: Optional[pulumi.Input['MwsCustomerManagedKeysGcpKeyInfoArgs']]):
        pulumi.set(self, "gcp_key_info", value)


@pulumi.input_type
class _MwsCustomerManagedKeysState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_key_info: Optional[pulumi.Input['MwsCustomerManagedKeysAwsKeyInfoArgs']] = None,
                 creation_time: Optional[pulumi.Input[_builtins.int]] = None,
                 customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcp_key_info: Optional[pulumi.Input['MwsCustomerManagedKeysGcpKeyInfoArgs']] = None,
                 use_cases: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering MwsCustomerManagedKeys resources.
        :param pulumi.Input[_builtins.str] account_id: Account Id that could be found in the top right corner of [Accounts Console](https://accounts.cloud.databricks.com/)
        :param pulumi.Input['MwsCustomerManagedKeysAwsKeyInfoArgs'] aws_key_info: This field is a block and is documented below. This conflicts with `gcp_key_info`
        :param pulumi.Input[_builtins.int] creation_time: (Integer) Time in epoch milliseconds when the customer key was created.
        :param pulumi.Input[_builtins.str] customer_managed_key_id: (String) ID of the encryption key configuration object.
        :param pulumi.Input['MwsCustomerManagedKeysGcpKeyInfoArgs'] gcp_key_info: This field is a block and is documented below. This conflicts with `aws_key_info`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] use_cases: *(since v0.3.4)* List of use cases for which this key will be used. *If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.* Possible values are:
               * `MANAGED_SERVICES` - for encryption of the workspace objects (notebooks, secrets) that are stored in the control plane
               * `STORAGE` - for encryption of the DBFS Storage & Cluster EBS Volumes
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if aws_key_info is not None:
            pulumi.set(__self__, "aws_key_info", aws_key_info)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if customer_managed_key_id is not None:
            pulumi.set(__self__, "customer_managed_key_id", customer_managed_key_id)
        if gcp_key_info is not None:
            pulumi.set(__self__, "gcp_key_info", gcp_key_info)
        if use_cases is not None:
            pulumi.set(__self__, "use_cases", use_cases)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account Id that could be found in the top right corner of [Accounts Console](https://accounts.cloud.databricks.com/)
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="awsKeyInfo")
    def aws_key_info(self) -> Optional[pulumi.Input['MwsCustomerManagedKeysAwsKeyInfoArgs']]:
        """
        This field is a block and is documented below. This conflicts with `gcp_key_info`
        """
        return pulumi.get(self, "aws_key_info")

    @aws_key_info.setter
    def aws_key_info(self, value: Optional[pulumi.Input['MwsCustomerManagedKeysAwsKeyInfoArgs']]):
        pulumi.set(self, "aws_key_info", value)

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (Integer) Time in epoch milliseconds when the customer key was created.
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "creation_time", value)

    @_builtins.property
    @pulumi.getter(name="customerManagedKeyId")
    def customer_managed_key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (String) ID of the encryption key configuration object.
        """
        return pulumi.get(self, "customer_managed_key_id")

    @customer_managed_key_id.setter
    def customer_managed_key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "customer_managed_key_id", value)

    @_builtins.property
    @pulumi.getter(name="gcpKeyInfo")
    def gcp_key_info(self) -> Optional[pulumi.Input['MwsCustomerManagedKeysGcpKeyInfoArgs']]:
        """
        This field is a block and is documented below. This conflicts with `aws_key_info`
        """
        return pulumi.get(self, "gcp_key_info")

    @gcp_key_info.setter
    def gcp_key_info(self, value: Optional[pulumi.Input['MwsCustomerManagedKeysGcpKeyInfoArgs']]):
        pulumi.set(self, "gcp_key_info", value)

    @_builtins.property
    @pulumi.getter(name="useCases")
    def use_cases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        *(since v0.3.4)* List of use cases for which this key will be used. *If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.* Possible values are:
        * `MANAGED_SERVICES` - for encryption of the workspace objects (notebooks, secrets) that are stored in the control plane
        * `STORAGE` - for encryption of the DBFS Storage & Cluster EBS Volumes
        """
        return pulumi.get(self, "use_cases")

    @use_cases.setter
    def use_cases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "use_cases", value)


@pulumi.type_token("databricks:index/mwsCustomerManagedKeys:MwsCustomerManagedKeys")
class MwsCustomerManagedKeys(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_key_info: Optional[pulumi.Input[Union['MwsCustomerManagedKeysAwsKeyInfoArgs', 'MwsCustomerManagedKeysAwsKeyInfoArgsDict']]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.int]] = None,
                 customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcp_key_info: Optional[pulumi.Input[Union['MwsCustomerManagedKeysGcpKeyInfoArgs', 'MwsCustomerManagedKeysGcpKeyInfoArgsDict']]] = None,
                 use_cases: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        > If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.

        ### Customer-managed key for managed services

        You must configure this during workspace creation

        ### For GCP

        ```python
        import pulumi
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Account Id that could be found in the top right corner of https://accounts.gcp.databricks.com/
        databricks_account_id = config.require_object("databricksAccountId")
        # Id of a google_kms_crypto_key
        cmek_resource_id = config.require_object("cmekResourceId")
        managed_services = databricks.MwsCustomerManagedKeys("managed_services",
            account_id=databricks_account_id,
            gcp_key_info={
                "kms_key_id": cmek_resource_id,
            },
            use_cases=["MANAGED_SERVICES"])
        ```

        ### Customer-managed key for workspace storage

        ### For GCP

        ```python
        import pulumi
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Account Id that could be found in the top right corner of https://accounts.gcp.databricks.com/
        databricks_account_id = config.require_object("databricksAccountId")
        # Id of a google_kms_crypto_key
        cmek_resource_id = config.require_object("cmekResourceId")
        storage = databricks.MwsCustomerManagedKeys("storage",
            account_id=databricks_account_id,
            gcp_key_info={
                "kms_key_id": cmek_resource_id,
            },
            use_cases=["STORAGE"])
        ```

        ## Related Resources

        The following resources are used in the same context:

        * Provisioning Databricks on AWS guide.
        * MwsCredentials to configure the cross-account role for creation of new workspaces within AWS.
        * MwsLogDelivery to configure delivery of [billable usage logs](https://docs.databricks.com/administration-guide/account-settings/billable-usage-delivery.html) and [audit logs](https://docs.databricks.com/administration-guide/account-settings/audit-logs.html).
        * MwsNetworks to [configure VPC](https://docs.databricks.com/administration-guide/cloud-configurations/aws/customer-managed-vpc.html) & subnets for new workspaces within AWS.
        * MwsStorageConfigurations to configure root bucket new workspaces within AWS.
        * MwsWorkspaces to set up [AWS and GCP workspaces](https://docs.databricks.com/getting-started/overview.html#e2-architecture-1).

        ## Import

        This resource can be imported by Databricks account ID and customer managed key ID.

        hcl

        import {

          to = databricks_mws_customer_managed_keys.this

          id = "<account_id>/<customer_managed_key_id>"

        }

        Alternatively, when using `terraform` version 1.4 or earlier, import using the `pulumi import` command:

        ```sh
        $ pulumi import databricks:index/mwsCustomerManagedKeys:MwsCustomerManagedKeys this '<account_id>/<customer_managed_key_id>'
        ```

        ~> This resource does not support updates. If your configuration does not match the existing resource,

           the next `pulumi up` will cause the resource to be destroyed and recreated. After importing,

           verify that the configuration matches the existing resource by running `pulumi preview`.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Id that could be found in the top right corner of [Accounts Console](https://accounts.cloud.databricks.com/)
        :param pulumi.Input[Union['MwsCustomerManagedKeysAwsKeyInfoArgs', 'MwsCustomerManagedKeysAwsKeyInfoArgsDict']] aws_key_info: This field is a block and is documented below. This conflicts with `gcp_key_info`
        :param pulumi.Input[_builtins.int] creation_time: (Integer) Time in epoch milliseconds when the customer key was created.
        :param pulumi.Input[_builtins.str] customer_managed_key_id: (String) ID of the encryption key configuration object.
        :param pulumi.Input[Union['MwsCustomerManagedKeysGcpKeyInfoArgs', 'MwsCustomerManagedKeysGcpKeyInfoArgsDict']] gcp_key_info: This field is a block and is documented below. This conflicts with `aws_key_info`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] use_cases: *(since v0.3.4)* List of use cases for which this key will be used. *If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.* Possible values are:
               * `MANAGED_SERVICES` - for encryption of the workspace objects (notebooks, secrets) that are stored in the control plane
               * `STORAGE` - for encryption of the DBFS Storage & Cluster EBS Volumes
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MwsCustomerManagedKeysArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        > If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.

        ### Customer-managed key for managed services

        You must configure this during workspace creation

        ### For GCP

        ```python
        import pulumi
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Account Id that could be found in the top right corner of https://accounts.gcp.databricks.com/
        databricks_account_id = config.require_object("databricksAccountId")
        # Id of a google_kms_crypto_key
        cmek_resource_id = config.require_object("cmekResourceId")
        managed_services = databricks.MwsCustomerManagedKeys("managed_services",
            account_id=databricks_account_id,
            gcp_key_info={
                "kms_key_id": cmek_resource_id,
            },
            use_cases=["MANAGED_SERVICES"])
        ```

        ### Customer-managed key for workspace storage

        ### For GCP

        ```python
        import pulumi
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Account Id that could be found in the top right corner of https://accounts.gcp.databricks.com/
        databricks_account_id = config.require_object("databricksAccountId")
        # Id of a google_kms_crypto_key
        cmek_resource_id = config.require_object("cmekResourceId")
        storage = databricks.MwsCustomerManagedKeys("storage",
            account_id=databricks_account_id,
            gcp_key_info={
                "kms_key_id": cmek_resource_id,
            },
            use_cases=["STORAGE"])
        ```

        ## Related Resources

        The following resources are used in the same context:

        * Provisioning Databricks on AWS guide.
        * MwsCredentials to configure the cross-account role for creation of new workspaces within AWS.
        * MwsLogDelivery to configure delivery of [billable usage logs](https://docs.databricks.com/administration-guide/account-settings/billable-usage-delivery.html) and [audit logs](https://docs.databricks.com/administration-guide/account-settings/audit-logs.html).
        * MwsNetworks to [configure VPC](https://docs.databricks.com/administration-guide/cloud-configurations/aws/customer-managed-vpc.html) & subnets for new workspaces within AWS.
        * MwsStorageConfigurations to configure root bucket new workspaces within AWS.
        * MwsWorkspaces to set up [AWS and GCP workspaces](https://docs.databricks.com/getting-started/overview.html#e2-architecture-1).

        ## Import

        This resource can be imported by Databricks account ID and customer managed key ID.

        hcl

        import {

          to = databricks_mws_customer_managed_keys.this

          id = "<account_id>/<customer_managed_key_id>"

        }

        Alternatively, when using `terraform` version 1.4 or earlier, import using the `pulumi import` command:

        ```sh
        $ pulumi import databricks:index/mwsCustomerManagedKeys:MwsCustomerManagedKeys this '<account_id>/<customer_managed_key_id>'
        ```

        ~> This resource does not support updates. If your configuration does not match the existing resource,

           the next `pulumi up` will cause the resource to be destroyed and recreated. After importing,

           verify that the configuration matches the existing resource by running `pulumi preview`.

        :param str resource_name: The name of the resource.
        :param MwsCustomerManagedKeysArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MwsCustomerManagedKeysArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_key_info: Optional[pulumi.Input[Union['MwsCustomerManagedKeysAwsKeyInfoArgs', 'MwsCustomerManagedKeysAwsKeyInfoArgsDict']]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.int]] = None,
                 customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcp_key_info: Optional[pulumi.Input[Union['MwsCustomerManagedKeysGcpKeyInfoArgs', 'MwsCustomerManagedKeysGcpKeyInfoArgsDict']]] = None,
                 use_cases: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MwsCustomerManagedKeysArgs.__new__(MwsCustomerManagedKeysArgs)

            if account_id is None and not opts.urn:
                raise TypeError("Missing required property 'account_id'")
            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["aws_key_info"] = aws_key_info
            __props__.__dict__["creation_time"] = creation_time
            __props__.__dict__["customer_managed_key_id"] = customer_managed_key_id
            __props__.__dict__["gcp_key_info"] = gcp_key_info
            if use_cases is None and not opts.urn:
                raise TypeError("Missing required property 'use_cases'")
            __props__.__dict__["use_cases"] = use_cases
        super(MwsCustomerManagedKeys, __self__).__init__(
            'databricks:index/mwsCustomerManagedKeys:MwsCustomerManagedKeys',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            aws_key_info: Optional[pulumi.Input[Union['MwsCustomerManagedKeysAwsKeyInfoArgs', 'MwsCustomerManagedKeysAwsKeyInfoArgsDict']]] = None,
            creation_time: Optional[pulumi.Input[_builtins.int]] = None,
            customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
            gcp_key_info: Optional[pulumi.Input[Union['MwsCustomerManagedKeysGcpKeyInfoArgs', 'MwsCustomerManagedKeysGcpKeyInfoArgsDict']]] = None,
            use_cases: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'MwsCustomerManagedKeys':
        """
        Get an existing MwsCustomerManagedKeys resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Id that could be found in the top right corner of [Accounts Console](https://accounts.cloud.databricks.com/)
        :param pulumi.Input[Union['MwsCustomerManagedKeysAwsKeyInfoArgs', 'MwsCustomerManagedKeysAwsKeyInfoArgsDict']] aws_key_info: This field is a block and is documented below. This conflicts with `gcp_key_info`
        :param pulumi.Input[_builtins.int] creation_time: (Integer) Time in epoch milliseconds when the customer key was created.
        :param pulumi.Input[_builtins.str] customer_managed_key_id: (String) ID of the encryption key configuration object.
        :param pulumi.Input[Union['MwsCustomerManagedKeysGcpKeyInfoArgs', 'MwsCustomerManagedKeysGcpKeyInfoArgsDict']] gcp_key_info: This field is a block and is documented below. This conflicts with `aws_key_info`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] use_cases: *(since v0.3.4)* List of use cases for which this key will be used. *If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.* Possible values are:
               * `MANAGED_SERVICES` - for encryption of the workspace objects (notebooks, secrets) that are stored in the control plane
               * `STORAGE` - for encryption of the DBFS Storage & Cluster EBS Volumes
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MwsCustomerManagedKeysState.__new__(_MwsCustomerManagedKeysState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["aws_key_info"] = aws_key_info
        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["customer_managed_key_id"] = customer_managed_key_id
        __props__.__dict__["gcp_key_info"] = gcp_key_info
        __props__.__dict__["use_cases"] = use_cases
        return MwsCustomerManagedKeys(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account Id that could be found in the top right corner of [Accounts Console](https://accounts.cloud.databricks.com/)
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="awsKeyInfo")
    def aws_key_info(self) -> pulumi.Output[Optional['outputs.MwsCustomerManagedKeysAwsKeyInfo']]:
        """
        This field is a block and is documented below. This conflicts with `gcp_key_info`
        """
        return pulumi.get(self, "aws_key_info")

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[_builtins.int]:
        """
        (Integer) Time in epoch milliseconds when the customer key was created.
        """
        return pulumi.get(self, "creation_time")

    @_builtins.property
    @pulumi.getter(name="customerManagedKeyId")
    def customer_managed_key_id(self) -> pulumi.Output[_builtins.str]:
        """
        (String) ID of the encryption key configuration object.
        """
        return pulumi.get(self, "customer_managed_key_id")

    @_builtins.property
    @pulumi.getter(name="gcpKeyInfo")
    def gcp_key_info(self) -> pulumi.Output[Optional['outputs.MwsCustomerManagedKeysGcpKeyInfo']]:
        """
        This field is a block and is documented below. This conflicts with `aws_key_info`
        """
        return pulumi.get(self, "gcp_key_info")

    @_builtins.property
    @pulumi.getter(name="useCases")
    def use_cases(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        *(since v0.3.4)* List of use cases for which this key will be used. *If you've used the resource before, please add `use_cases = ["MANAGED_SERVICES"]` to keep the previous behaviour.* Possible values are:
        * `MANAGED_SERVICES` - for encryption of the workspace objects (notebooks, secrets) that are stored in the control plane
        * `STORAGE` - for encryption of the DBFS Storage & Cluster EBS Volumes
        """
        return pulumi.get(self, "use_cases")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSchemasResult',
    'AwaitableGetSchemasResult',
    'get_schemas',
    'get_schemas_output',
]

@pulumi.output_type
class GetSchemasResult:
    """
    A collection of values returned by getSchemas.
    """
    def __init__(__self__, catalog_name=None, id=None, ids=None, provider_config=None):
        if catalog_name and not isinstance(catalog_name, str):
            raise TypeError("Expected argument 'catalog_name' to be a str")
        pulumi.set(__self__, "catalog_name", catalog_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> _builtins.str:
        return pulumi.get(self, "catalog_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ids(self) -> Sequence[_builtins.str]:
        """
        set of Schema full names: *`catalog`.`schema`*
        """
        return pulumi.get(self, "ids")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetSchemasProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetSchemasResult(GetSchemasResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSchemasResult(
            catalog_name=self.catalog_name,
            id=self.id,
            ids=self.ids,
            provider_config=self.provider_config)


def get_schemas(catalog_name: Optional[_builtins.str] = None,
                ids: Optional[Sequence[_builtins.str]] = None,
                provider_config: Optional[Union['GetSchemasProviderConfigArgs', 'GetSchemasProviderConfigArgsDict']] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSchemasResult:
    """
    Retrieves a list of Schema ids, that were created by Pulumi or manually, so that special handling could be applied.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Listing all schemas in a _sandbox_ databricks_catalog:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    sandbox = databricks.get_schemas(catalog_name="sandbox")
    pulumi.export("allSandboxSchemas", sandbox)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Schema to manage schemas within Unity Catalog.
    * Catalog to manage catalogs within Unity Catalog.


    :param _builtins.str catalog_name: Name of databricks_catalog
    :param Sequence[_builtins.str] ids: set of Schema full names: *`catalog`.`schema`*
    :param Union['GetSchemasProviderConfigArgs', 'GetSchemasProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['catalogName'] = catalog_name
    __args__['ids'] = ids
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getSchemas:getSchemas', __args__, opts=opts, typ=GetSchemasResult).value

    return AwaitableGetSchemasResult(
        catalog_name=pulumi.get(__ret__, 'catalog_name'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_schemas_output(catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                       ids: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                       provider_config: Optional[pulumi.Input[Optional[Union['GetSchemasProviderConfigArgs', 'GetSchemasProviderConfigArgsDict']]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSchemasResult]:
    """
    Retrieves a list of Schema ids, that were created by Pulumi or manually, so that special handling could be applied.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Listing all schemas in a _sandbox_ databricks_catalog:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    sandbox = databricks.get_schemas(catalog_name="sandbox")
    pulumi.export("allSandboxSchemas", sandbox)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Schema to manage schemas within Unity Catalog.
    * Catalog to manage catalogs within Unity Catalog.


    :param _builtins.str catalog_name: Name of databricks_catalog
    :param Sequence[_builtins.str] ids: set of Schema full names: *`catalog`.`schema`*
    :param Union['GetSchemasProviderConfigArgs', 'GetSchemasProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['catalogName'] = catalog_name
    __args__['ids'] = ids
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getSchemas:getSchemas', __args__, opts=opts, typ=GetSchemasResult)
    return __ret__.apply(lambda __response__: GetSchemasResult(
        catalog_name=pulumi.get(__response__, 'catalog_name'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        provider_config=pulumi.get(__response__, 'provider_config')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetWorkspaceEntityTagAssignmentsResult',
    'AwaitableGetWorkspaceEntityTagAssignmentsResult',
    'get_workspace_entity_tag_assignments',
    'get_workspace_entity_tag_assignments_output',
]

@pulumi.output_type
class GetWorkspaceEntityTagAssignmentsResult:
    """
    A collection of values returned by getWorkspaceEntityTagAssignments.
    """
    def __init__(__self__, entity_id=None, entity_type=None, id=None, page_size=None, tag_assignments=None):
        if entity_id and not isinstance(entity_id, str):
            raise TypeError("Expected argument 'entity_id' to be a str")
        pulumi.set(__self__, "entity_id", entity_id)
        if entity_type and not isinstance(entity_type, str):
            raise TypeError("Expected argument 'entity_type' to be a str")
        pulumi.set(__self__, "entity_type", entity_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if tag_assignments and not isinstance(tag_assignments, list):
            raise TypeError("Expected argument 'tag_assignments' to be a list")
        pulumi.set(__self__, "tag_assignments", tag_assignments)

    @_builtins.property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> _builtins.str:
        """
        (string) - The identifier of the entity to which the tag is assigned
        """
        return pulumi.get(self, "entity_id")

    @_builtins.property
    @pulumi.getter(name="entityType")
    def entity_type(self) -> _builtins.str:
        """
        (string) - The type of entity to which the tag is assigned. Allowed values are dashboards, geniespaces
        """
        return pulumi.get(self, "entity_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter(name="tagAssignments")
    def tag_assignments(self) -> Sequence['outputs.GetWorkspaceEntityTagAssignmentsTagAssignmentResult']:
        return pulumi.get(self, "tag_assignments")


class AwaitableGetWorkspaceEntityTagAssignmentsResult(GetWorkspaceEntityTagAssignmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWorkspaceEntityTagAssignmentsResult(
            entity_id=self.entity_id,
            entity_type=self.entity_type,
            id=self.id,
            page_size=self.page_size,
            tag_assignments=self.tag_assignments)


def get_workspace_entity_tag_assignments(entity_id: Optional[_builtins.str] = None,
                                         entity_type: Optional[_builtins.str] = None,
                                         page_size: Optional[_builtins.int] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWorkspaceEntityTagAssignmentsResult:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source allows you to retrieve tag assignments that have been applied to a particular workspace scoped entity.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    dashboard_tags = databricks.get_workspace_entity_tag_assignments(entity_type="dashboards",
        entity_id="2807324866692453")
    geniespace_tags = databricks.get_workspace_entity_tag_assignments(entity_type="geniespaces",
        entity_id="2807324866692453")
    ```


    :param _builtins.str entity_id: The identifier of the entity to which the tag is assigned
    :param _builtins.str entity_type: The type of entity to which the tag is assigned. Allowed values are dashboards, geniespaces
    :param _builtins.int page_size: Optional. Maximum number of tag assignments to return in a single page
    """
    __args__ = dict()
    __args__['entityId'] = entity_id
    __args__['entityType'] = entity_type
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getWorkspaceEntityTagAssignments:getWorkspaceEntityTagAssignments', __args__, opts=opts, typ=GetWorkspaceEntityTagAssignmentsResult).value

    return AwaitableGetWorkspaceEntityTagAssignmentsResult(
        entity_id=pulumi.get(__ret__, 'entity_id'),
        entity_type=pulumi.get(__ret__, 'entity_type'),
        id=pulumi.get(__ret__, 'id'),
        page_size=pulumi.get(__ret__, 'page_size'),
        tag_assignments=pulumi.get(__ret__, 'tag_assignments'))
def get_workspace_entity_tag_assignments_output(entity_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                entity_type: Optional[pulumi.Input[_builtins.str]] = None,
                                                page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetWorkspaceEntityTagAssignmentsResult]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source allows you to retrieve tag assignments that have been applied to a particular workspace scoped entity.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    dashboard_tags = databricks.get_workspace_entity_tag_assignments(entity_type="dashboards",
        entity_id="2807324866692453")
    geniespace_tags = databricks.get_workspace_entity_tag_assignments(entity_type="geniespaces",
        entity_id="2807324866692453")
    ```


    :param _builtins.str entity_id: The identifier of the entity to which the tag is assigned
    :param _builtins.str entity_type: The type of entity to which the tag is assigned. Allowed values are dashboards, geniespaces
    :param _builtins.int page_size: Optional. Maximum number of tag assignments to return in a single page
    """
    __args__ = dict()
    __args__['entityId'] = entity_id
    __args__['entityType'] = entity_type
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getWorkspaceEntityTagAssignments:getWorkspaceEntityTagAssignments', __args__, opts=opts, typ=GetWorkspaceEntityTagAssignmentsResult)
    return __ret__.apply(lambda __response__: GetWorkspaceEntityTagAssignmentsResult(
        entity_id=pulumi.get(__response__, 'entity_id'),
        entity_type=pulumi.get(__response__, 'entity_type'),
        id=pulumi.get(__response__, 'id'),
        page_size=pulumi.get(__response__, 'page_size'),
        tag_assignments=pulumi.get(__response__, 'tag_assignments')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetTagPolicyResult',
    'AwaitableGetTagPolicyResult',
    'get_tag_policy',
    'get_tag_policy_output',
]

@pulumi.output_type
class GetTagPolicyResult:
    """
    A collection of values returned by getTagPolicy.
    """
    def __init__(__self__, create_time=None, description=None, id=None, tag_key=None, update_time=None, values=None):
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if tag_key and not isinstance(tag_key, str):
            raise TypeError("Expected argument 'tag_key' to be a str")
        pulumi.set(__self__, "tag_key", tag_key)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if values and not isinstance(values, list):
            raise TypeError("Expected argument 'values' to be a list")
        pulumi.set(__self__, "values", values)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> _builtins.str:
        """
        (string) - Timestamp when the tag policy was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        (string)
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        (string)
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> _builtins.str:
        """
        (string)
        """
        return pulumi.get(self, "tag_key")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> _builtins.str:
        """
        (string) - Timestamp when the tag policy was last updated
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter
    def values(self) -> Sequence['outputs.GetTagPolicyValueResult']:
        """
        (list of Value)
        """
        return pulumi.get(self, "values")


class AwaitableGetTagPolicyResult(GetTagPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTagPolicyResult(
            create_time=self.create_time,
            description=self.description,
            id=self.id,
            tag_key=self.tag_key,
            update_time=self.update_time,
            values=self.values)


def get_tag_policy(tag_key: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTagPolicyResult:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single tag policy by its tag key.

    The following resources are often used in the same context:

    * EntityTagAssignment for assigning tags to supported Unity Catalog entities.
    * WorkspaceEntityTagAssignment for assigning tags to supported workspace entities.
    * PolicyInfo for defining ABAC policies using governed tags.
    * AccessControlRuleSet for managing account-level and individual tag policy permissions.

    > **Note** This resource can only be used with a workspace-level provider!

    ## Example Usage

    Referring to a tag policy by its tag key:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    example_tag_policy = databricks.get_tag_policy(tag_key="example_tag_key")
    ```
    """
    __args__ = dict()
    __args__['tagKey'] = tag_key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getTagPolicy:getTagPolicy', __args__, opts=opts, typ=GetTagPolicyResult).value

    return AwaitableGetTagPolicyResult(
        create_time=pulumi.get(__ret__, 'create_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        tag_key=pulumi.get(__ret__, 'tag_key'),
        update_time=pulumi.get(__ret__, 'update_time'),
        values=pulumi.get(__ret__, 'values'))
def get_tag_policy_output(tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTagPolicyResult]:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single tag policy by its tag key.

    The following resources are often used in the same context:

    * EntityTagAssignment for assigning tags to supported Unity Catalog entities.
    * WorkspaceEntityTagAssignment for assigning tags to supported workspace entities.
    * PolicyInfo for defining ABAC policies using governed tags.
    * AccessControlRuleSet for managing account-level and individual tag policy permissions.

    > **Note** This resource can only be used with a workspace-level provider!

    ## Example Usage

    Referring to a tag policy by its tag key:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    example_tag_policy = databricks.get_tag_policy(tag_key="example_tag_key")
    ```
    """
    __args__ = dict()
    __args__['tagKey'] = tag_key
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getTagPolicy:getTagPolicy', __args__, opts=opts, typ=GetTagPolicyResult)
    return __ret__.apply(lambda __response__: GetTagPolicyResult(
        create_time=pulumi.get(__response__, 'create_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        tag_key=pulumi.get(__response__, 'tag_key'),
        update_time=pulumi.get(__response__, 'update_time'),
        values=pulumi.get(__response__, 'values')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PostgresEndpointArgs', 'PostgresEndpoint']

@pulumi.input_type
class PostgresEndpointArgs:
    def __init__(__self__, *,
                 parent: pulumi.Input[_builtins.str],
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input['PostgresEndpointSpecArgs']] = None):
        """
        The set of arguments for constructing a PostgresEndpoint resource.
        :param pulumi.Input[_builtins.str] parent: The branch containing this endpoint.
               Format: projects/{project_id}/branches/{branch_id}
        :param pulumi.Input[_builtins.str] endpoint_id: The ID to use for the Endpoint, which will become the final component of
               the endpoint's resource name.
               
               This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/
        :param pulumi.Input['PostgresEndpointSpecArgs'] spec: The desired state of an Endpoint
        """
        pulumi.set(__self__, "parent", parent)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Input[_builtins.str]:
        """
        The branch containing this endpoint.
        Format: projects/{project_id}/branches/{branch_id}
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID to use for the Endpoint, which will become the final component of
        the endpoint's resource name.

        This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['PostgresEndpointSpecArgs']]:
        """
        The desired state of an Endpoint
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['PostgresEndpointSpecArgs']]):
        pulumi.set(self, "spec", value)


@pulumi.input_type
class _PostgresEndpointState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input['PostgresEndpointSpecArgs']] = None,
                 status: Optional[pulumi.Input['PostgresEndpointStatusArgs']] = None,
                 uid: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PostgresEndpoint resources.
        :param pulumi.Input[_builtins.str] create_time: (string) - A timestamp indicating when the compute endpoint was created
        :param pulumi.Input[_builtins.str] endpoint_id: The ID to use for the Endpoint, which will become the final component of
               the endpoint's resource name.
               
               This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/
        :param pulumi.Input[_builtins.str] name: (string) - The resource name of the endpoint.
               Format: projects/{project_id}/branches/{branch_id}/endpoints/{endpoint_id}
        :param pulumi.Input[_builtins.str] parent: The branch containing this endpoint.
               Format: projects/{project_id}/branches/{branch_id}
        :param pulumi.Input['PostgresEndpointSpecArgs'] spec: The desired state of an Endpoint
        :param pulumi.Input['PostgresEndpointStatusArgs'] status: (EndpointStatus) - The current status of an Endpoint
        :param pulumi.Input[_builtins.str] uid: (string) - System generated unique ID for the endpoint
        :param pulumi.Input[_builtins.str] update_time: (string) - A timestamp indicating when the compute endpoint was last updated
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - A timestamp indicating when the compute endpoint was created
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID to use for the Endpoint, which will become the final component of
        the endpoint's resource name.

        This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The resource name of the endpoint.
        Format: projects/{project_id}/branches/{branch_id}/endpoints/{endpoint_id}
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The branch containing this endpoint.
        Format: projects/{project_id}/branches/{branch_id}
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['PostgresEndpointSpecArgs']]:
        """
        The desired state of an Endpoint
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['PostgresEndpointSpecArgs']]):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['PostgresEndpointStatusArgs']]:
        """
        (EndpointStatus) - The current status of an Endpoint
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['PostgresEndpointStatusArgs']]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - System generated unique ID for the endpoint
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "uid", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - A timestamp indicating when the compute endpoint was last updated
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("databricks:index/postgresEndpoint:PostgresEndpoint")
class PostgresEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input[Union['PostgresEndpointSpecArgs', 'PostgresEndpointSpecArgsDict']]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_postgres_endpoint.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/postgresEndpoint:PostgresEndpoint this "name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] endpoint_id: The ID to use for the Endpoint, which will become the final component of
               the endpoint's resource name.
               
               This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/
        :param pulumi.Input[_builtins.str] parent: The branch containing this endpoint.
               Format: projects/{project_id}/branches/{branch_id}
        :param pulumi.Input[Union['PostgresEndpointSpecArgs', 'PostgresEndpointSpecArgsDict']] spec: The desired state of an Endpoint
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PostgresEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_postgres_endpoint.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/postgresEndpoint:PostgresEndpoint this "name"
        ```

        :param str resource_name: The name of the resource.
        :param PostgresEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PostgresEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input[Union['PostgresEndpointSpecArgs', 'PostgresEndpointSpecArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PostgresEndpointArgs.__new__(PostgresEndpointArgs)

            __props__.__dict__["endpoint_id"] = endpoint_id
            if parent is None and not opts.urn:
                raise TypeError("Missing required property 'parent'")
            __props__.__dict__["parent"] = parent
            __props__.__dict__["spec"] = spec
            __props__.__dict__["create_time"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["uid"] = None
            __props__.__dict__["update_time"] = None
        super(PostgresEndpoint, __self__).__init__(
            'databricks:index/postgresEndpoint:PostgresEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent: Optional[pulumi.Input[_builtins.str]] = None,
            spec: Optional[pulumi.Input[Union['PostgresEndpointSpecArgs', 'PostgresEndpointSpecArgsDict']]] = None,
            status: Optional[pulumi.Input[Union['PostgresEndpointStatusArgs', 'PostgresEndpointStatusArgsDict']]] = None,
            uid: Optional[pulumi.Input[_builtins.str]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None) -> 'PostgresEndpoint':
        """
        Get an existing PostgresEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: (string) - A timestamp indicating when the compute endpoint was created
        :param pulumi.Input[_builtins.str] endpoint_id: The ID to use for the Endpoint, which will become the final component of
               the endpoint's resource name.
               
               This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/
        :param pulumi.Input[_builtins.str] name: (string) - The resource name of the endpoint.
               Format: projects/{project_id}/branches/{branch_id}/endpoints/{endpoint_id}
        :param pulumi.Input[_builtins.str] parent: The branch containing this endpoint.
               Format: projects/{project_id}/branches/{branch_id}
        :param pulumi.Input[Union['PostgresEndpointSpecArgs', 'PostgresEndpointSpecArgsDict']] spec: The desired state of an Endpoint
        :param pulumi.Input[Union['PostgresEndpointStatusArgs', 'PostgresEndpointStatusArgsDict']] status: (EndpointStatus) - The current status of an Endpoint
        :param pulumi.Input[_builtins.str] uid: (string) - System generated unique ID for the endpoint
        :param pulumi.Input[_builtins.str] update_time: (string) - A timestamp indicating when the compute endpoint was last updated
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PostgresEndpointState.__new__(_PostgresEndpointState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["endpoint_id"] = endpoint_id
        __props__.__dict__["name"] = name
        __props__.__dict__["parent"] = parent
        __props__.__dict__["spec"] = spec
        __props__.__dict__["status"] = status
        __props__.__dict__["uid"] = uid
        __props__.__dict__["update_time"] = update_time
        return PostgresEndpoint(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - A timestamp indicating when the compute endpoint was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID to use for the Endpoint, which will become the final component of
        the endpoint's resource name.

        This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/
        """
        return pulumi.get(self, "endpoint_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The resource name of the endpoint.
        Format: projects/{project_id}/branches/{branch_id}/endpoints/{endpoint_id}
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Output[_builtins.str]:
        """
        The branch containing this endpoint.
        Format: projects/{project_id}/branches/{branch_id}
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter
    def spec(self) -> pulumi.Output['outputs.PostgresEndpointSpec']:
        """
        The desired state of an Endpoint
        """
        return pulumi.get(self, "spec")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.PostgresEndpointStatus']:
        """
        (EndpointStatus) - The current status of an Endpoint
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def uid(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - System generated unique ID for the endpoint
        """
        return pulumi.get(self, "uid")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - A timestamp indicating when the compute endpoint was last updated
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetStorageCredentialResult',
    'AwaitableGetStorageCredentialResult',
    'get_storage_credential',
    'get_storage_credential_output',
]

@pulumi.output_type
class GetStorageCredentialResult:
    """
    A collection of values returned by getStorageCredential.
    """
    def __init__(__self__, id=None, name=None, provider_config=None, storage_credential_info=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if storage_credential_info and not isinstance(storage_credential_info, dict):
            raise TypeError("Expected argument 'storage_credential_info' to be a dict")
        pulumi.set(__self__, "storage_credential_info", storage_credential_info)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Unique ID of storage credential.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetStorageCredentialProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="storageCredentialInfo")
    def storage_credential_info(self) -> 'outputs.GetStorageCredentialStorageCredentialInfoResult':
        """
        array of objects with information about storage credential.
        """
        return pulumi.get(self, "storage_credential_info")


class AwaitableGetStorageCredentialResult(GetStorageCredentialResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStorageCredentialResult(
            id=self.id,
            name=self.name,
            provider_config=self.provider_config,
            storage_credential_info=self.storage_credential_info)


def get_storage_credential(id: Optional[_builtins.str] = None,
                           name: Optional[_builtins.str] = None,
                           provider_config: Optional[Union['GetStorageCredentialProviderConfigArgs', 'GetStorageCredentialProviderConfigArgsDict']] = None,
                           storage_credential_info: Optional[Union['GetStorageCredentialStorageCredentialInfoArgs', 'GetStorageCredentialStorageCredentialInfoArgsDict']] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStorageCredentialResult:
    """
    Retrieves details about a StorageCredential that were created by Pulumi or manually.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Getting details of an existing storage credential in the metastore

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_storage_credential(name="this")
    pulumi.export("createdBy", this.storage_credential_info.created_by)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * get_storage_credentials to get names of all credentials
    * StorageCredential to manage Storage Credentials within Unity Catalog.


    :param _builtins.str id: Unique ID of storage credential.
    :param _builtins.str name: The name of the storage credential
    :param Union['GetStorageCredentialProviderConfigArgs', 'GetStorageCredentialProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    :param Union['GetStorageCredentialStorageCredentialInfoArgs', 'GetStorageCredentialStorageCredentialInfoArgsDict'] storage_credential_info: array of objects with information about storage credential.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    __args__['storageCredentialInfo'] = storage_credential_info
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getStorageCredential:getStorageCredential', __args__, opts=opts, typ=GetStorageCredentialResult).value

    return AwaitableGetStorageCredentialResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        storage_credential_info=pulumi.get(__ret__, 'storage_credential_info'))
def get_storage_credential_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  name: Optional[pulumi.Input[_builtins.str]] = None,
                                  provider_config: Optional[pulumi.Input[Optional[Union['GetStorageCredentialProviderConfigArgs', 'GetStorageCredentialProviderConfigArgsDict']]]] = None,
                                  storage_credential_info: Optional[pulumi.Input[Optional[Union['GetStorageCredentialStorageCredentialInfoArgs', 'GetStorageCredentialStorageCredentialInfoArgsDict']]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetStorageCredentialResult]:
    """
    Retrieves details about a StorageCredential that were created by Pulumi or manually.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Getting details of an existing storage credential in the metastore

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_storage_credential(name="this")
    pulumi.export("createdBy", this.storage_credential_info.created_by)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * get_storage_credentials to get names of all credentials
    * StorageCredential to manage Storage Credentials within Unity Catalog.


    :param _builtins.str id: Unique ID of storage credential.
    :param _builtins.str name: The name of the storage credential
    :param Union['GetStorageCredentialProviderConfigArgs', 'GetStorageCredentialProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    :param Union['GetStorageCredentialStorageCredentialInfoArgs', 'GetStorageCredentialStorageCredentialInfoArgsDict'] storage_credential_info: array of objects with information about storage credential.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    __args__['storageCredentialInfo'] = storage_credential_info
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getStorageCredential:getStorageCredential', __args__, opts=opts, typ=GetStorageCredentialResult)
    return __ret__.apply(lambda __response__: GetStorageCredentialResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        storage_credential_info=pulumi.get(__response__, 'storage_credential_info')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAppsResult',
    'AwaitableGetAppsResult',
    'get_apps',
    'get_apps_output',
]

@pulumi.output_type
class GetAppsResult:
    """
    A collection of values returned by getApps.
    """
    def __init__(__self__, apps=None, id=None, provider_config=None):
        if apps and not isinstance(apps, list):
            raise TypeError("Expected argument 'apps' to be a list")
        pulumi.set(__self__, "apps", apps)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def apps(self) -> Sequence['outputs.GetAppsAppResult']:
        return pulumi.get(self, "apps")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetAppsProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetAppsResult(GetAppsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppsResult(
            apps=self.apps,
            id=self.id,
            provider_config=self.provider_config)


def get_apps(provider_config: Optional[Union['GetAppsProviderConfigArgs', 'GetAppsProviderConfigArgsDict']] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppsResult:
    """
    > This data source can only be used with a workspace-level provider!

    [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html) run directly on a customer’s Databricks instance, integrate with their data, use and extend Databricks services, and enable users to interact through single sign-on. This resource creates the application but does not handle app deployment, which should be handled separately as part of your CI/CD pipeline.

    This data source allows you to fetch information about all Databricks Apps within a workspace.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all_apps = databricks.get_apps()
    ```

    ## Related Resources

    The following resources are used in the same context:

    * App to manage [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html).
    * SqlEndpoint to manage Databricks SQL [Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
    * ModelServing to serve this model on a Databricks serving endpoint.
    * Secret to manage [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code.
    """
    __args__ = dict()
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getApps:getApps', __args__, opts=opts, typ=GetAppsResult).value

    return AwaitableGetAppsResult(
        apps=pulumi.get(__ret__, 'apps'),
        id=pulumi.get(__ret__, 'id'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_apps_output(provider_config: Optional[pulumi.Input[Optional[Union['GetAppsProviderConfigArgs', 'GetAppsProviderConfigArgsDict']]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAppsResult]:
    """
    > This data source can only be used with a workspace-level provider!

    [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html) run directly on a customer’s Databricks instance, integrate with their data, use and extend Databricks services, and enable users to interact through single sign-on. This resource creates the application but does not handle app deployment, which should be handled separately as part of your CI/CD pipeline.

    This data source allows you to fetch information about all Databricks Apps within a workspace.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all_apps = databricks.get_apps()
    ```

    ## Related Resources

    The following resources are used in the same context:

    * App to manage [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html).
    * SqlEndpoint to manage Databricks SQL [Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
    * ModelServing to serve this model on a Databricks serving endpoint.
    * Secret to manage [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code.
    """
    __args__ = dict()
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getApps:getApps', __args__, opts=opts, typ=GetAppsResult)
    return __ret__.apply(lambda __response__: GetAppsResult(
        apps=pulumi.get(__response__, 'apps'),
        id=pulumi.get(__response__, 'id'),
        provider_config=pulumi.get(__response__, 'provider_config')))
